[Scummvm-cvs-logs] SF.net SVN: scummvm: [28785] scummvm/trunk/engines/saga/animation.cpp

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Sat Sep 1 14:43:22 CEST 2007


Revision: 28785
          http://scummvm.svn.sourceforge.net/scummvm/?rev=28785&view=rev
Author:   thebluegr
Date:     2007-09-01 05:43:22 -0700 (Sat, 01 Sep 2007)

Log Message:
-----------
Modified the workaround for the IHNM end credits animation

Modified Paths:
--------------
    scummvm/trunk/engines/saga/animation.cpp

Modified: scummvm/trunk/engines/saga/animation.cpp
===================================================================
--- scummvm/trunk/engines/saga/animation.cpp	2007-09-01 11:39:51 UTC (rev 28784)
+++ scummvm/trunk/engines/saga/animation.cpp	2007-09-01 12:43:22 UTC (rev 28785)
@@ -386,10 +386,9 @@
 
 	// Cache frame offsets
 
-	// WORKAROUND: Cutaway #4 is ending credits. For some reason it
-	// has wrong number of frames specified in its header. So we
-	// calculate it here:
-	if (animId == MAX_ANIMATIONS + 4)
+	// WORKAROUND: Cutaway with background resource ID 37 (loaded as cutaway #4) is ending credits.
+	// For some reason it has wrong number of frames specified in its header. So we calculate it here:
+	if (animId > MAX_ANIMATIONS && _cutawayListLength > 4 && _cutawayList[4].backgroundResourceId == 37)
 		anim->maxFrame = fillFrameOffsets(anim, false);
 
 	anim->frameOffsets = (size_t *)malloc((anim->maxFrame + 1) * sizeof(*anim->frameOffsets));


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list